@@ -11,48 +11,61 @@ void (*f_anthy_set_string)(anthy_context_t ac, char *);
 extern int eng_ph;
 extern gint64 key_press_time;
 static GtkWidget *event_box_anthy;
+gint64 current_time();
 
 struct {
   char *en;
   char *ro;
 } anthy_romaji_map[] = {
+{"xtu",	"っ"},
+{"xtsu",	"っ"},
+{"ltu",	"っ"},
+{"ltsu",	"っ"},
+
 {"-",	"ー"},
 {"a",	"あ"},
 {"i",	"い"},
 {"u",	"う"},
 {"e",	"え"},
 {"o",	"お"},
+
 {"xa",	"ぁ"},
 {"xi",	"ぃ"},
 {"xu",	"ぅ"},
 {"xe",	"ぇ"},
 {"xo",	"ぉ"},
+
 {"la",	"ぁ"},
 {"li",	"ぃ"},
 {"lu",	"ぅ"},
 {"le",	"ぇ"},
 {"lo",	"ぉ"},
+
 {"wi",	"うぃ"},
 {"we",	"うぇ"},
 {"wha",	"うぁ"},
 {"whi",	"うぃ"},
 {"whe",	"うぇ"},
 {"who",	"うぉ"},
+
 {"va",	"う゛ぁ"},
 {"vi",	"う゛ぃ"},
 {"vu",	"う゛"},
 {"ve",	"う゛ぇ"},
 {"vo",	"う゛ぉ"},
+
 {"ka",	"か"},
 {"ki",	"き"},
 {"ku",	"く"},
 {"ke",	"け"},
 {"ko",	"こ"},
+
 {"ga",	"が"},
 {"gi",	"ぎ"},
 {"gu",	"ぐ"},
 {"ge",	"げ"},
 {"go",	"ご"},
+
 {"kya",	"きゃ"},
 {"kyi",	"きぃ"},
 {"kyu",	"きゅ"},
@@ -63,16 +76,19 @@ struct {
 {"gyu",	"ぎゅ"},
 {"gye",	"ぎぇ"},
 {"gyo",	"ぎょ"},
+
 {"sa",	"さ"},
 {"si",	"し"},
 {"su",	"す"},
 {"se",	"せ"},
 {"so",	"そ"},
+
 {"za",	"ざ"},
 {"zi",	"じ"},
 {"zu",	"ず"},
 {"ze",	"ぜ"},
 {"zo",	"ぞ"},
+
 {"sya",	"しゃ"},
 {"syi",	"しぃ"},
 {"syu",	"しゅ"},
@@ -104,42 +120,44 @@ struct {
 {"tsu",	"つ"},
 {"te",	"て"},
 {"to",	"と"},
+
 {"da",	"だ"},
 {"di",	"ぢ"},
 {"du",	"づ"},
 {"de",	"で"},
 {"do",	"ど"},
-{"xtu",	"っ"},
-{"xtsu","っ"	""},
-{"ltu",	"っ"},
-{"ltsu","っ"},
-{"s",	"っ"}, // ni[s]sin
-{"p",	"っ"}, // ni[p]pon
+
+
 {"tya",	"ちゃ"},
 {"tyi",	"ちぃ"},
 {"tyu",	"ちゅ"},
 {"tye",	"ちぇ"},
 {"tyo",	"ちょ"},
+
 {"cha",	"ちゃ"},
 {"chi",	"ち"},
 {"chu",	"ちゅ"},
 {"che",	"ちぇ"},
 {"cho",	"ちょ"},
+
 {"dya",	"ぢゃ"},
 {"dyi",	"ぢぃ"},
 {"dyu",	"ぢゅ"},
 {"dye",	"ぢぇ"},
 {"dyo",	"ぢょ"},
+
 {"tha",	"てゃ"},
 {"thi",	"てぃ"},
 {"thu",	"てゅ"},
 {"the",	"てぇ"},
 {"tho",	"てょ"},
+
 {"dha",	"でゃ"},
 {"dhi",	"でぃ"},
 {"dhu",	"でゅ"},
 {"dhe",	"でぇ"},
 {"dho",	"でょ"},
+
 {"na",	"な"},
 {"ni",	"に"},
 {"nu",	"ぬ"},
@@ -150,22 +168,25 @@ struct {
 {"nyu",	"にゅ"},
 {"nye",	"にぇ"},
 {"nyo",	"にょ"},
+
 {"ha",	"は"},
 {"hi",	"ひ"},
 {"hu",	"ふ"},
-{"fu",	"ふ"},
 {"he",	"へ"},
 {"ho",	"ほ"},
+
 {"ba",	"ば"},
 {"bi",	"び"},
 {"bu",	"ぶ"},
 {"be",	"べ"},
 {"bo",	"ぼ"},
+
 {"pa",	"ぱ"},
 {"pi",	"ぴ"},
 {"pu",	"ぷ"},
 {"pe",	"ぺ"},
 {"po",	"ぽ"},
+
 {"hya",	"ひゃ"},
 {"hyi",	"ひぃ"},
 {"hyu",	"ひゅ"},
@@ -181,16 +202,19 @@ struct {
 {"pyu",	"ぴゅ"},
 {"pye",	"ぴぇ"},
 {"pyo",	"ぴょ"},
+
 {"fa",	"ふぁ"},
 {"fi",	"ふぃ"},
 {"fu",	"ふ"},
 {"fe",	"ふぇ"},
 {"fo",	"ふぉ"},
+
 {"ma",	"ま"},
 {"mi",	"み"},
 {"mu",	"む"},
 {"me",	"め"},
 {"mo",	"も"},
+
 {"mya",	"みゃ"},
 {"myi",	"みぃ"},
 {"myu",	"みゅ"},
@@ -205,11 +229,13 @@ struct {
 {"lyo",	"ょ"},
 {"xyo",	"ょ"},
 {"yo",	"よ"},
+
 {"ra",	"ら"},
 {"ri",	"り"},
 {"ru",	"る"},
 {"re",	"れ"},
 {"ro",	"ろ"},
+
 {"rya",	"りゃ"},
 {"ryi",	"りぃ"},
 {"ryu",	"りゅ"},
@@ -331,6 +357,15 @@ void parse_key()
   int i;
   int preN=0, eqN=0, sendpreN=0;
   unsigned char eq, sendpre_i = 255;
+  static char ch2[]="kstzdhbrpfgvcjmwy";
+
+  if (keysN==2 && keys[0]==keys[1] && strchr(ch2, keys[0])) {
+    append_jp(0);
+    keys[1]=0;
+    keysN=1;
+    return;
+  }
+
   for(i=0; i < anthy_romaji_mapN; i++) {
     char *en = anthy_romaji_map[i].en;
     char *ro = anthy_romaji_map[i].ro;
@@ -395,6 +430,8 @@ static void cursor_markup(int idx, char *s)
 
 void minimize_win_anthy()
 {
+  if (!win_anthy)
+    return;
   gtk_window_resize(GTK_WINDOW(win_anthy), 32, 12);
 }
 
@@ -402,6 +439,9 @@ static void disp_input()
 {
   int i;
 
+  if (gcin_edit_display & GCIN_EDIT_DISPLAY_ON_THE_SPOT)
+    return;
+
 //  printf("cursor %d\n", cursor);
   clear_seg_label();
   for(i=0; i < jpN; i++) {
@@ -448,6 +488,15 @@ void delete_jpstr(idx)
   jpN--;
 }
 
+static void clear_all()
+{
+  clear_seg_label();
+  jpN=0;
+  keys[0]=0;
+  keysN = 0;
+  segN = 0;
+  auto_hide();
+}
 
 
 static void send_seg()
@@ -460,13 +509,9 @@ static void send_seg()
     seg[i].selidx = 0;
   }
 
-  clear_seg_label();
-  jpN=0;
-  keysN = 0;
-
 //  printf("sent convert '%s'\n", out);
   send_text(out);
-  segN = 0;
+  clear_all();
 }
 
 static char merge_jp(char out[])
@@ -518,7 +563,8 @@ static void disp_select()
   int x,y;
   get_widget_xy(win_anthy, seg[cursor].label, &x, &y);
 //  printf("%x cusor %d %d\n", win_anthy, cursor, x);
-  disp_selections(x, win_y+win_yl);
+  y = gcin_edit_display==GCIN_EDIT_DISPLAY_ON_THE_SPOT?win_y:win_y+win_yl;
+  disp_selections(x, y);
 }
 
 static void load_seg()
@@ -545,7 +591,9 @@ static void load_seg()
         }
 
         state=STATE_CONVERT;
-        cursor = 0;
+//        cursor = 0;
+        if (cursor >= acs.nr_segment)
+          cursor = acs.nr_segment - 1;
         disp_convert();
       }
       keysN=0;
@@ -587,8 +635,10 @@ gboolean feedkey_anthy(int kv, int kvstate)
   int shift_m=(kvstate&ShiftMask) > 0;
 //  printf("%x %c  %d\n", kv, kv, shift_m);
 
-  if (kv==XK_Shift_L||kv==XK_Shift_R)
+  if (kv==XK_Shift_L||kv==XK_Shift_R) {
+    puts("shift");
     key_press_time = current_time();
+  }
 
   if (!eng_ph)
     return 0;
@@ -598,6 +648,12 @@ gboolean feedkey_anthy(int kv, int kvstate)
 //  printf("empty %d\n", is_empty);
 
   switch (kv) {
+    case XK_F11:
+      system("kasumi &");
+      return TRUE;
+    case XK_F12:
+      system("kasumi -a &");
+      return TRUE;
     case XK_Return:
       if (is_empty)
         return FALSE;
@@ -856,7 +912,7 @@ int init_win_anthy()
     GtkWidget *dialog = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL,
                                      GTK_MESSAGE_ERROR,
                                      GTK_BUTTONS_CLOSE,
-                                     "Cannot init anthy. Please install anthy.");
+                                     "Cannot init anthy. incompatible anthy.so ?");
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
     return FALSE;
@@ -927,7 +983,9 @@ int anthy_visible()
 extern gboolean force_show;
 void show_win_anthy()
 {
-  if (!gcin_pop_up_win || !is_empty() || force_show) {
+  if (gcin_edit_display & GCIN_EDIT_DISPLAY_ON_THE_SPOT)
+    return;
+  if (!gcin_pop_up_win || !is_empty() || force_show ) {
     if (!anthy_visible())
       gtk_widget_show(win_anthy);
     show_win_sym();
@@ -1010,3 +1068,83 @@ int feedkey_anthy_release(KeySym xkey, int kbstate)
         return 0;
   }
 }
+
+#include "im-client/gcin-im-client-attr.h"
+
+int anthy_get_preedit(char *str, GCIN_PREEDIT_ATTR attr[], int *pcursor)
+{
+  int i;
+  int tn=0;
+
+//  dbg("anthy_get_preedit\n");
+  str[0]=0;
+  *pcursor=0;
+
+  attr[0].flag=GCIN_PREEDIT_ATTR_FLAG_UNDERLINE;
+  attr[0].ofs0=0;
+  int attrN=0;
+  int ch_N=0;
+
+  if (state==STATE_CONVERT) {
+    if (segN)
+      attrN=1;
+
+    for(i=0; i < segN; i++) {
+      char *s = gtk_label_get_text(GTK_LABEL(seg[i].label));
+      int N = utf8_str_N(s);
+      ch_N+=N;
+      if (i < cursor)
+        *pcursor+=N;
+      if (i==cursor) {
+        attr[1].ofs0=*pcursor;
+        attr[1].ofs1=*pcursor+N;
+        attr[1].flag=GCIN_PREEDIT_ATTR_FLAG_REVERSE;
+        attrN++;
+      }
+      strcat(str, s);
+    }
+
+    attr[0].ofs1 = ch_N;
+  } else {
+    if (jpN)
+      attrN=1;
+
+    for(i=0;i < jpN; i++) {
+      char *s=anthy_romaji_map[jp[i]].ro;
+      int N = utf8_str_N(s);
+      ch_N+=N;
+      if (i < cursor)
+        *pcursor+= N;
+      if (i==cursor) {
+        attr[1].ofs0=*pcursor;
+        attr[1].ofs1=*pcursor+N;
+        attr[1].flag=GCIN_PREEDIT_ATTR_FLAG_REVERSE;
+        attrN++;
+      }
+      strcat(str, s);
+    }
+
+    strcat(str, keys);
+    attr[0].ofs1 = ch_N + keysN;
+  }
+
+ret:
+  return attrN;
+}
+
+
+void gcin_anthy_reset()
+{
+  if (!win_anthy)
+    return;
+  clear_all();
+}
+
+void get_win_anthy_geom()
+{
+  if (!win_anthy)
+    return;
+  gtk_window_get_position(GTK_WINDOW(win_anthy), &win_x, &win_y);
+
+  get_win_size(win_anthy, &win_xl, &win_yl);
+}
